# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/contest.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/judge/contest.proto',
  package='eolymp.judge',
  syntax='proto3',
  serialized_options=b'Z1github.com/eolymp/contracts/go/eolymp/judge;judge',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/judge/contest.proto\x12\x0c\x65olymp.judge\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\xc7\x03\n\x07\x43ontest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12(\n\x04type\x18\x03 \x01(\x0e\x32\x1a.eolymp.judge.Contest.Type\x12-\n\tstarts_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\tstarts_in\x18\x0b \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x07\x65nds_at\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x07\x65nds_in\x18\x10 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x10\n\x08\x64uration\x18\x0c \x01(\x05\x12,\n\x06status\x18\x14 \x01(\x0e\x32\x1c.eolymp.judge.Contest.Status\x12\x0e\n\x06public\x18\x1e \x01(\x08\x12\x0e\n\x06\x64omain\x18( \x01(\t\">\n\x06Status\x12\r\n\tNO_STATUS\x10\x00\x12\r\n\tSCHEDULED\x10\x01\x12\x08\n\x04OPEN\x10\x02\x12\x0c\n\x08\x43OMPLETE\x10\x03\"\"\n\x04Type\x12\x0b\n\x07NO_TYPE\x10\x00\x12\r\n\tCHALLENGE\x10\x01\x42\x33Z1github.com/eolymp/contracts/go/eolymp/judge;judgeb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])



_CONTEST_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='eolymp.judge.Contest.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_STATUS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEDULED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPEN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPLETE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=467,
  serialized_end=529,
)
_sym_db.RegisterEnumDescriptor(_CONTEST_STATUS)

_CONTEST_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='eolymp.judge.Contest.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_TYPE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHALLENGE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=531,
  serialized_end=565,
)
_sym_db.RegisterEnumDescriptor(_CONTEST_TYPE)


_CONTEST = _descriptor.Descriptor(
  name='Contest',
  full_name='eolymp.judge.Contest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.judge.Contest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.judge.Contest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='eolymp.judge.Contest.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='starts_at', full_name='eolymp.judge.Contest.starts_at', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='starts_in', full_name='eolymp.judge.Contest.starts_in', index=4,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ends_at', full_name='eolymp.judge.Contest.ends_at', index=5,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ends_in', full_name='eolymp.judge.Contest.ends_in', index=6,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='eolymp.judge.Contest.duration', index=7,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='eolymp.judge.Contest.status', index=8,
      number=20, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public', full_name='eolymp.judge.Contest.public', index=9,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='domain', full_name='eolymp.judge.Contest.domain', index=10,
      number=40, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONTEST_STATUS,
    _CONTEST_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=110,
  serialized_end=565,
)

_CONTEST.fields_by_name['type'].enum_type = _CONTEST_TYPE
_CONTEST.fields_by_name['starts_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CONTEST.fields_by_name['starts_in'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CONTEST.fields_by_name['ends_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CONTEST.fields_by_name['ends_in'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CONTEST.fields_by_name['status'].enum_type = _CONTEST_STATUS
_CONTEST_STATUS.containing_type = _CONTEST
_CONTEST_TYPE.containing_type = _CONTEST
DESCRIPTOR.message_types_by_name['Contest'] = _CONTEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Contest = _reflection.GeneratedProtocolMessageType('Contest', (_message.Message,), {
  'DESCRIPTOR' : _CONTEST,
  '__module__' : 'eolymp.judge.contest_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.judge.Contest)
  })
_sym_db.RegisterMessage(Contest)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
