# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/apollo/apollo.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.apollo import submission_pb2 as eolymp_dot_apollo_dot_submission__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/apollo/apollo.proto',
  package='eolymp.apollo',
  syntax='proto3',
  serialized_options=b'Z3github.com/eolymp/contracts/go/eolymp/apollo;apollo',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/apollo/apollo.proto\x12\reolymp.apollo\x1a\x1d\x65olymp/annotations/http.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1e\x65olymp/apollo/submission.proto\"I\n\x15\x43reateSubmissionInput\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\x0c\n\x04lang\x18\x02 \x01(\t\x12\x0e\n\x06source\x18\x03 \x01(\t\"/\n\x16\x43reateSubmissionOutput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"0\n\x17\x44\x65scribeSubmissionInput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"I\n\x18\x44\x65scribeSubmissionOutput\x12-\n\nsubmission\x18\x01 \x01(\x0b\x32\x19.eolymp.apollo.Submission2\xfe\x02\n\x06\x41pollo\x12\xb4\x01\n\x10\x43reateSubmission\x12$.eolymp.apollo.CreateSubmissionInput\x1a%.eolymp.apollo.CreateSubmissionOutput\"S\x82\xe3\n\x1b\x8a\xe3\n\x17\x61pollo:submission:write\x82\xd3\xe4\x93\x02.\")/apollo/problems/{problem_id}/submissions:\x01*\x12\xbc\x01\n\x12\x44\x65scribeSubmission\x12&.eolymp.apollo.DescribeSubmissionInput\x1a\'.eolymp.apollo.DescribeSubmissionOutput\"U\x82\xe3\n\x1a\x8a\xe3\n\x16\x61pollo:submission:read\x82\xd3\xe4\x93\x02\x31\x12#/apollo/submissions/{submission_id}b\nsubmissionB5Z3github.com/eolymp/contracts/go/eolymp/apollo;apollob\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_http__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_scope__pb2.DESCRIPTOR,eolymp_dot_apollo_dot_submission__pb2.DESCRIPTOR,])




_CREATESUBMISSIONINPUT = _descriptor.Descriptor(
  name='CreateSubmissionInput',
  full_name='eolymp.apollo.CreateSubmissionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem_id', full_name='eolymp.apollo.CreateSubmissionInput.problem_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lang', full_name='eolymp.apollo.CreateSubmissionInput.lang', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='eolymp.apollo.CreateSubmissionInput.source', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=213,
)


_CREATESUBMISSIONOUTPUT = _descriptor.Descriptor(
  name='CreateSubmissionOutput',
  full_name='eolymp.apollo.CreateSubmissionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission_id', full_name='eolymp.apollo.CreateSubmissionOutput.submission_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=215,
  serialized_end=262,
)


_DESCRIBESUBMISSIONINPUT = _descriptor.Descriptor(
  name='DescribeSubmissionInput',
  full_name='eolymp.apollo.DescribeSubmissionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission_id', full_name='eolymp.apollo.DescribeSubmissionInput.submission_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=264,
  serialized_end=312,
)


_DESCRIBESUBMISSIONOUTPUT = _descriptor.Descriptor(
  name='DescribeSubmissionOutput',
  full_name='eolymp.apollo.DescribeSubmissionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='submission', full_name='eolymp.apollo.DescribeSubmissionOutput.submission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=387,
)

_DESCRIBESUBMISSIONOUTPUT.fields_by_name['submission'].message_type = eolymp_dot_apollo_dot_submission__pb2._SUBMISSION
DESCRIPTOR.message_types_by_name['CreateSubmissionInput'] = _CREATESUBMISSIONINPUT
DESCRIPTOR.message_types_by_name['CreateSubmissionOutput'] = _CREATESUBMISSIONOUTPUT
DESCRIPTOR.message_types_by_name['DescribeSubmissionInput'] = _DESCRIBESUBMISSIONINPUT
DESCRIPTOR.message_types_by_name['DescribeSubmissionOutput'] = _DESCRIBESUBMISSIONOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateSubmissionInput = _reflection.GeneratedProtocolMessageType('CreateSubmissionInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESUBMISSIONINPUT,
  '__module__' : 'eolymp.apollo.apollo_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.CreateSubmissionInput)
  })
_sym_db.RegisterMessage(CreateSubmissionInput)

CreateSubmissionOutput = _reflection.GeneratedProtocolMessageType('CreateSubmissionOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESUBMISSIONOUTPUT,
  '__module__' : 'eolymp.apollo.apollo_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.CreateSubmissionOutput)
  })
_sym_db.RegisterMessage(CreateSubmissionOutput)

DescribeSubmissionInput = _reflection.GeneratedProtocolMessageType('DescribeSubmissionInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESUBMISSIONINPUT,
  '__module__' : 'eolymp.apollo.apollo_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.DescribeSubmissionInput)
  })
_sym_db.RegisterMessage(DescribeSubmissionInput)

DescribeSubmissionOutput = _reflection.GeneratedProtocolMessageType('DescribeSubmissionOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESUBMISSIONOUTPUT,
  '__module__' : 'eolymp.apollo.apollo_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.apollo.DescribeSubmissionOutput)
  })
_sym_db.RegisterMessage(DescribeSubmissionOutput)


DESCRIPTOR._options = None

_APOLLO = _descriptor.ServiceDescriptor(
  name='Apollo',
  full_name='eolymp.apollo.Apollo',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=390,
  serialized_end=772,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateSubmission',
    full_name='eolymp.apollo.Apollo.CreateSubmission',
    index=0,
    containing_service=None,
    input_type=_CREATESUBMISSIONINPUT,
    output_type=_CREATESUBMISSIONOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027apollo:submission:write\202\323\344\223\002.\")/apollo/problems/{problem_id}/submissions:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeSubmission',
    full_name='eolymp.apollo.Apollo.DescribeSubmission',
    index=1,
    containing_service=None,
    input_type=_DESCRIBESUBMISSIONINPUT,
    output_type=_DESCRIBESUBMISSIONOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026apollo:submission:read\202\323\344\223\0021\022#/apollo/submissions/{submission_id}b\nsubmission',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_APOLLO)

DESCRIPTOR.services_by_name['Apollo'] = _APOLLO

# @@protoc_insertion_point(module_scope)
